import path from "node:path";
import { getConfig, generator } from "css-var-extract";
let lock = false;
const checkLock = () => lock;
const setLock = (bool) => {
  lock = bool;
};
const unpluginCssVarExtractFactory = (options) => {
  let root = process.cwd();
  let userConfig = options;
  const getFilePaths = () => userConfig.files.map(
    (file) => path.isAbsolute(file) ? file : path.join(root, file)
  );
  const generate = async () => {
    if (checkLock()) {
      return;
    }
    setLock(true);
    try {
      await generator(userConfig);
    } catch (err) {
      console.error(err);
      console.info();
    } finally {
      setLock(false);
    }
  };
  const handleFile = async (file, event) => {
    const filePath = path.normalize(file);
    if (filePath === path.join(root, "cve.config.json")) {
      userConfig = getConfig(true, userConfig, root);
      return;
    }
    if (event === "update" && filePath === path.resolve(userConfig.output)) {
      return;
    }
    if (getFilePaths().includes(filePath)) {
      await generate();
    }
  };
  return {
    name: "router-generator-plugin",
    async watchChange(id, { event }) {
      await handleFile(id, event);
    },
    vite: {
      async configResolved(config) {
        root = config.root;
        userConfig = getConfig(true, userConfig, root);
        await generate();
      }
    },
    async rspack(compiler) {
      userConfig = getConfig(true, userConfig, root);
      if (compiler.options.mode === "production") {
        await generate();
      } else {
        const filePaths = getFilePaths();
        const chokidar = await import("chokidar");
        chokidar.watch(filePaths).on("add", async () => {
          await generate();
        });
      }
    },
    async webpack(compiler) {
      userConfig = getConfig(true, userConfig, root);
      if (compiler.options.mode === "production") {
        await generate();
        compiler.hooks.done.tap("unplugin:css-var-extract", () => {
          console.info(
            "✅ unplugin:css-var-extract: generation done"
          );
          setTimeout(() => {
            process.exit(0);
          });
        });
      } else {
        const filePaths = getFilePaths();
        const chokidar = await import("chokidar");
        chokidar.watch(filePaths).on("add", async () => {
          await generate();
        });
      }
    }
  };
};
export {
  unpluginCssVarExtractFactory as u
};
//# sourceMappingURL=css-var-extract-plugin-DqoZzai3.js.map
